=== modified file 'drizzled/db.cc'
--- drizzled/db.cc	2010-01-25 19:52:38 +0000
+++ drizzled/db.cc	2010-02-04 21:00:20 +0000
@@ -75,7 +75,7 @@
 {
   message::Schema db;
 
-  get_database_metadata(db_name, &db);
+  get_database_metadata(db_name, db);
 
   /* If for some reason the db.opt file lacks a collation,
      we just return the default */
@@ -129,13 +129,14 @@
     close(fd);
     return errno;
   }
-
   close(fd);
+
   return 0;
 }
 
-int get_database_metadata(const char *dbname, message::Schema *db)
+int get_database_metadata(const std::string &dbname, message::Schema &schema_message)
 {
+  int rc= 0;
   char db_opt_path[FN_REFLEN];
   size_t length;
 
@@ -144,22 +145,48 @@
     to avoid table name to file name encoding.
   */
   length= build_table_filename(db_opt_path, sizeof(db_opt_path),
-                              dbname, "", false);
+                               dbname.c_str(), "", false);
   strcpy(db_opt_path + length, MY_DB_OPT_FILE);
 
   int fd= open(db_opt_path, O_RDONLY);
 
-  if (fd == -1)
-    return errno;
+  if (fd == -1 && errno != ENOENT)
+    rc= errno;
 
-  if (!db->ParseFromFileDescriptor(fd))
+  /**
+    @note If parsing fails, either someone has done a "mkdir" or has deleted their opt file.
+    So what do we do? We muddle through the adventure by generating 
+    one with a name in it, and the charset set to the default.
+  */
+  if (fd == -1 || not schema_message.ParseFromFileDescriptor(fd))
   {
-    close(fd);
-    return -1;
+    struct stat directory_stat_buffer;
+
+    /* Remove the opt file name and see if we can just open up the directory. */
+    db_opt_path[length]= 0;
+    if (lstat(db_opt_path, &directory_stat_buffer))
+    {
+      rc= errno;
+    }
+    else if (not S_ISDIR(directory_stat_buffer.st_mode))
+    {
+      rc= -1;
+    }
+    else
+    {
+      schema_message.set_name(dbname);
+      rc= 0;
+    }
+
+#if 0 
+    //@todo fill this in with something totally acceptable
+    schema_message.set_collation("utf8_general_ci"); 
+#endif
   }
+
   close(fd);
 
-  return 0;
+  return rc;
 }
 
 /*

=== modified file 'drizzled/db.h'
--- drizzled/db.h	2010-01-25 19:52:38 +0000
+++ drizzled/db.h	2010-02-04 21:00:20 +0000
@@ -31,7 +31,7 @@
 bool mysql_change_db(Session *session, const LEX_STRING *new_db_name, bool force_switch);
 
 bool check_db_dir_existence(const char *db_name);
-int get_database_metadata(const char *dbname, drizzled::message::Schema *db);
+int get_database_metadata(const std::string &dbname, drizzled::message::Schema &db);
 
 const CHARSET_INFO *get_default_db_collation(const char *db_name);
 

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2010-02-03 16:56:27 +0000
+++ drizzled/drizzled.cc	2010-02-04 21:00:20 +0000
@@ -1304,16 +1304,16 @@
   if (default_collation_name)
   {
     const CHARSET_INFO * const default_collation= get_charset_by_name(default_collation_name);
-    if (!default_collation)
+    if (not default_collation)
     {
-          errmsg_printf(ERRMSG_LVL_ERROR, _(ER(ER_UNKNOWN_COLLATION)), default_collation_name);
+      errmsg_printf(ERRMSG_LVL_ERROR, _(ER(ER_UNKNOWN_COLLATION)), default_collation_name);
       return 1;
     }
-    if (!my_charset_same(default_charset_info, default_collation))
+    if (not my_charset_same(default_charset_info, default_collation))
     {
-          errmsg_printf(ERRMSG_LVL_ERROR, _(ER(ER_COLLATION_CHARSET_MISMATCH)),
-                      default_collation_name,
-                      default_charset_info->csname);
+      errmsg_printf(ERRMSG_LVL_ERROR, _(ER(ER_COLLATION_CHARSET_MISMATCH)),
+                    default_collation_name,
+                    default_charset_info->csname);
       return 1;
     }
     default_charset_info= default_collation;
@@ -1323,7 +1323,7 @@
 
   global_system_variables.optimizer_switch= 0;
 
-  if (!(character_set_filesystem=
+  if (not (character_set_filesystem=
         get_charset_by_csname(character_set_filesystem_name, MY_CS_PRIMARY)))
     return 1;
   global_system_variables.character_set_filesystem= character_set_filesystem;

=== modified file 'drizzled/plugin/storage_engine.cc'
--- drizzled/plugin/storage_engine.cc	2010-01-28 19:25:49 +0000
+++ drizzled/plugin/storage_engine.cc	2010-02-04 21:00:20 +0000
@@ -952,7 +952,7 @@
   }
   else
   {
-    ret= get_database_metadata(schema_name.c_str(), &proto);
+    ret= get_database_metadata(schema_name.c_str(), proto);
   }
 
   return ret == 0 ? true : false;

=== modified file 'drizzled/plugin/storage_engine.h'
--- drizzled/plugin/storage_engine.h	2010-02-03 16:56:27 +0000
+++ drizzled/plugin/storage_engine.h	2010-02-04 21:00:20 +0000
@@ -419,8 +419,10 @@
                        bool generate_warning);
   static void getTableNames(const std::string& db_name, std::set<std::string> &set_of_names);
 
+  // @note All schema methods defined here
   static void getSchemaNames(std::set<std::string>& set_of_names);
   static bool getSchemaDefinition(const std::string &schema_name, message::Schema &proto);
+ 
 
   static inline const std::string &resolveName(const StorageEngine *engine)
   {

=== modified file 'drizzled/plugin/table_function.cc'
--- drizzled/plugin/table_function.cc	2010-02-03 20:00:13 +0000
+++ drizzled/plugin/table_function.cc	2010-02-04 21:00:20 +0000
@@ -24,6 +24,8 @@
 #include <drizzled/gettext.h>
 #include "drizzled/plugin/registry.h"
 #include "drizzled/global_charset_info.h"
+#include "drizzled/session.h"
+#include "drizzled/current_session.h"
 
 #include <vector>
 
@@ -185,3 +187,16 @@
 
   columns_iterator++;
 }
+
+bool plugin::TableFunction::Generator::isWild(const std::string &predicate)
+{
+
+  if (not (current_session)->lex->wild)
+    return false;
+
+  bool match=  wild_case_compare(system_charset_info,
+                                 predicate.c_str(),
+                                 (current_session)->lex->wild->c_str());
+
+  return match;
+}

=== modified file 'drizzled/plugin/table_function.h'
--- drizzled/plugin/table_function.h	2010-02-03 20:00:13 +0000
+++ drizzled/plugin/table_function.h	2010-02-04 21:00:20 +0000
@@ -32,6 +32,9 @@
 #include <string>
 #include <set>
 
+extern int wild_case_compare(const CHARSET_INFO * const cs, 
+                             const char *str,const char *wildstr);
+
 namespace drizzled
 {
 
@@ -107,6 +110,7 @@
     void push(const std::string& arg);
     void push(bool arg);
 
+    bool isWild(const std::string &predicate);
   };
 
   void define(drizzled::message::Table &arg)

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2010-01-25 20:44:56 +0000
+++ drizzled/session.cc	2010-02-04 21:00:20 +0000
@@ -914,8 +914,15 @@
   @return  NULL on failure, or pointer to the LEX_STRING object
 */
 LEX_STRING *Session::make_lex_string(LEX_STRING *lex_str,
-                                 const char* str, uint32_t length,
-                                 bool allocate_lex_string)
+                                     const std::string &str,
+                                     bool allocate_lex_string)
+{
+  return make_lex_string(lex_str, str.c_str(), str.length(), allocate_lex_string);
+}
+
+LEX_STRING *Session::make_lex_string(LEX_STRING *lex_str,
+                                     const char* str, uint32_t length,
+                                     bool allocate_lex_string)
 {
   if (allocate_lex_string)
     if (!(lex_str= (LEX_STRING *)alloc(sizeof(LEX_STRING))))

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2010-01-25 20:44:56 +0000
+++ drizzled/session.h	2010-02-04 21:00:20 +0000
@@ -1048,6 +1048,9 @@
   LEX_STRING *make_lex_string(LEX_STRING *lex_str,
                               const char* str, uint32_t length,
                               bool allocate_lex_string);
+  LEX_STRING *make_lex_string(LEX_STRING *lex_str,
+                              const std::string &str,
+                              bool allocate_lex_string);
 
   void add_changed_table(Table *table);
   void add_changed_table(const char *key, long key_length);

=== modified file 'drizzled/show.cc'
--- drizzled/show.cc	2010-02-04 20:42:07 +0000
+++ drizzled/show.cc	2010-02-04 21:00:20 +0000
@@ -72,7 +72,7 @@
 
 
 
-int wild_case_compare(const CHARSET_INFO * const cs, const char *str,const char *wildstr)
+int wild_case_compare(const CHARSET_INFO * const cs, const char *str, const char *wildstr)
 {
   register int flag;
   while (*wildstr)
@@ -271,20 +271,20 @@
 {
   message::Schema schema;
 
-  if (!my_strcasecmp(system_charset_info, dbname,
-                     INFORMATION_SCHEMA_NAME.c_str()))
+  if (not my_strcasecmp(system_charset_info, dbname,
+                        INFORMATION_SCHEMA_NAME.c_str()))
   {
     dbname= INFORMATION_SCHEMA_NAME.c_str();
   }
-  else if (!my_strcasecmp(system_charset_info, dbname,
-                     "data_dictionary"))
+  else if (not my_strcasecmp(system_charset_info, dbname,
+                             "data_dictionary"))
   {
     dbname= "data_dictionary";
   }
   else
   {
-    int r= get_database_metadata(dbname, &schema);
-    if(r < 0)
+    int r= get_database_metadata(dbname, schema);
+    if (r < 0)
       return true;
   }
 

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2010-02-03 20:00:13 +0000
+++ drizzled/sql_parse.cc	2010-02-04 21:00:20 +0000
@@ -353,6 +353,42 @@
     1                 out of memory or SHOW commands are not allowed
                       in this version of the server.
 */
+static bool _schema_select(Session *session, Select_Lex *sel,
+                           const string& schema_table_name)
+{
+  LEX_STRING db, table;
+  /*
+     We have to make non const db_name & table_name
+     because of lower_case_table_names
+  */
+  session->make_lex_string(&db, "data_dictionary", sizeof("data_dictionary"), false);
+  session->make_lex_string(&table, schema_table_name, false);
+
+  if (! sel->add_table_to_list(session, new Table_ident(db, table),
+                               NULL, 0, TL_READ))
+  {
+    return true;
+  }
+  return false;
+}
+
+int prepare_new_schema_table(Session *session, LEX *lex,
+                             const string& schema_table_name)
+{
+  Select_Lex *schema_select_lex= NULL;
+
+  Select_Lex *select_lex= lex->current_select;
+  assert(select_lex);
+  if (_schema_select(session, select_lex, schema_table_name))
+  {
+    return(1);
+  }
+  TableList *table_list= (TableList*) select_lex->table_list.first;
+  assert(table_list);
+  table_list->schema_select_lex= schema_select_lex;
+
+  return 0;
+}
 
 int prepare_schema_table(Session *session, LEX *lex, Table_ident *table_ident,
                          const string& schema_table_name)

=== modified file 'drizzled/sql_parse.h'
--- drizzled/sql_parse.h	2009-12-25 09:18:10 +0000
+++ drizzled/sql_parse.h	2010-02-04 21:00:20 +0000
@@ -79,6 +79,9 @@
 int prepare_schema_table(Session *session, LEX *lex, Table_ident *table_ident,
                          const std::string& schema_table_name);
 
+int prepare_new_schema_table(Session *session, LEX *lex,
+                             const std::string& schema_table_name);
+
 Item * all_any_subquery_creator(Item *left_expr,
                                 chooser_compare_func_creator cmp,
                                 bool all,

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2009-12-27 00:49:03 +0000
+++ drizzled/sql_select.cc	2010-02-04 21:00:20 +0000
@@ -346,18 +346,18 @@
 */
 bool mysql_select(Session *session,
                   Item ***rref_pointer_array,
-	                TableList *tables, 
+                  TableList *tables, 
                   uint32_t wild_num, 
                   List<Item> &fields,
-	                COND *conds, 
+                  COND *conds, 
                   uint32_t og_num,  
                   order_st *order, 
                   order_st *group,
-	                Item *having, 
+                  Item *having, 
                   uint64_t select_options,
-	                select_result *result, 
+                  select_result *result, 
                   Select_Lex_Unit *unit,
-	                Select_Lex *select_lex)
+                  Select_Lex *select_lex)
 {
   bool err;
   bool free_join= 1;

=== modified file 'drizzled/sql_string.h'
--- drizzled/sql_string.h	2010-01-21 01:37:22 +0000
+++ drizzled/sql_string.h	2010-02-04 21:00:20 +0000
@@ -119,6 +119,14 @@
       (void) realloc(str_length);
     return Ptr;
   }
+  inline char *c_str()
+  {
+    if (Ptr && str_length < Alloced_length)
+      Ptr[str_length]=0;
+    else
+      (void) realloc(str_length);
+    return Ptr;
+  }
   void append_identifier(const char *name, uint32_t length);
 
   void set(String &str,uint32_t offset,uint32_t arg_length)

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2010-02-04 20:42:07 +0000
+++ drizzled/sql_yacc.yy	2010-02-04 21:00:20 +0000
@@ -4827,24 +4827,91 @@
            DATABASES show_wild
            {
              LEX *lex= Lex;
-             lex->sql_command= SQLCOM_SHOW_DATABASES;
+             lex->sql_command= SQLCOM_SELECT;
              lex->statement=
                new(std::nothrow) statement::Select(YYSession);
              if (lex->statement == NULL)
                DRIZZLE_YYABORT;
-             if (prepare_schema_table(YYSession, lex, 0, "OLD_SCHEMATA"))
+
+             Session *session= YYSession;
+
+             std::string column_name= "Database";
+             if (Lex->wild)
+             {
+               column_name.append(" (");
+               column_name.append(Lex->wild->c_str());
+               column_name.append(")");
+             }
+
+             if (Lex->current_select->where)
+             {
+               if (prepare_new_schema_table(YYSession, lex, "SCHEMAS"))
+                 DRIZZLE_YYABORT;
+             }
+             else
+             {
+               if (prepare_new_schema_table(YYSession, lex, "SCHEMA_NAMES"))
+                 DRIZZLE_YYABORT;
+             }
+
+             Item_field *my_field= new Item_field(&session->lex->current_select->context, NULL, NULL, "SCHEMA_NAME");
+             my_field->is_autogenerated_name= false;
+             my_field->set_name(column_name.c_str(), column_name.length(), system_charset_info);
+
+             if (session->add_item_to_list(my_field))
                DRIZZLE_YYABORT;
            }
          | TABLES opt_db show_wild
            {
              LEX *lex= Lex;
-             lex->sql_command= SQLCOM_SHOW_TABLES;
+             lex->sql_command= SQLCOM_SELECT;
              lex->statement=
                new(std::nothrow) statement::Select(YYSession);
              if (lex->statement == NULL)
                DRIZZLE_YYABORT;
-             lex->select_lex.db= $2;
-             if (prepare_schema_table(YYSession, lex, 0, "TABLE_NAMES"))
+
+              Session *session= YYSession;
+
+              std::string column_name= "Tables_in_";
+
+              if ($2)
+              {
+                message::Schema schema_message;
+                column_name.append($2);
+                lex->select_lex.db= $2;
+                if (not plugin::StorageEngine::getSchemaDefinition($2, schema_message))
+                {
+                  my_error(ER_BAD_DB_ERROR, MYF(0), $2);
+                }
+              }
+              else
+              {
+                column_name.append(session->db);
+              }
+
+             if (Lex->wild)
+             {
+               column_name.append(" (");
+               column_name.append(Lex->wild->c_str());
+               column_name.append(")");
+             }
+
+             if (Lex->current_select->where)
+             {
+               if (prepare_new_schema_table(YYSession, lex, "TABLES"))
+                 DRIZZLE_YYABORT;
+             }
+             else
+             {
+               if (prepare_new_schema_table(YYSession, lex, "LOCAL_TABLE_NAMES"))
+                 DRIZZLE_YYABORT;
+             }
+
+             Item_field *my_field= new Item_field(&session->lex->current_select->context, NULL, NULL, "TABLE_NAME");
+             my_field->is_autogenerated_name= false;
+             my_field->set_name(column_name.c_str(), column_name.length(), system_charset_info);
+
+             if (session->add_item_to_list(my_field))
                DRIZZLE_YYABORT;
            }
          | TABLE_SYM STATUS_SYM opt_db show_wild

=== modified file 'plugin/data_engine/schemas.cc'
--- plugin/data_engine/schemas.cc	2010-02-04 02:40:55 +0000
+++ plugin/data_engine/schemas.cc	2010-02-04 21:00:20 +0000
@@ -42,7 +42,7 @@
 */
 bool SchemasTool::Generator::checkSchema()
 {
-  return false;
+  return isWild(schema_name());
 }
 
 bool SchemasTool::Generator::nextSchemaCore()

=== modified file 'plugin/data_engine/schemas.h'
--- plugin/data_engine/schemas.h	2010-02-04 02:40:55 +0000
+++ plugin/data_engine/schemas.h	2010-02-04 21:00:20 +0000
@@ -31,7 +31,6 @@
 #include "drizzled/message/schema.pb.h"
 #include "drizzled/field.h"
 
-
 class SchemasTool : public drizzled::plugin::TableFunction
 {
 public:

=== modified file 'plugin/data_engine/tables.cc'
--- plugin/data_engine/tables.cc	2010-02-04 02:40:55 +0000
+++ plugin/data_engine/tables.cc	2010-02-04 21:00:20 +0000
@@ -77,6 +77,9 @@
                                              &table_proto);
   }
 
+  if (checkTableName())
+    return false;
+
   return true;
 }
 
@@ -84,6 +87,10 @@
 {
   while (not nextTableCore())
   {
+
+    if (is_tables_primed && table_iterator != table_names.end())
+      continue;
+
     if (not nextSchema())
       return false;
     is_tables_primed= false;
@@ -92,6 +99,11 @@
   return true;
 }
 
+bool TablesTool::Generator::checkTableName()
+{
+  return isWild(table_name());
+}
+
 bool TablesTool::Generator::populate()
 {
   if (not nextTable())
@@ -182,5 +194,9 @@
 {
   Session *session= current_session;
 
+  if (session->lex->select_lex.db)
+  {
+    return schema_name().compare(session->lex->select_lex.db);
+  }
   return session->db.compare(schema_name());
 }

=== modified file 'plugin/data_engine/tables.h'
--- plugin/data_engine/tables.h	2010-02-04 02:40:55 +0000
+++ plugin/data_engine/tables.h	2010-02-04 21:00:20 +0000
@@ -65,6 +65,7 @@
 
     bool populate();
     bool nextTable();
+    bool checkTableName();
   };
 
   Generator *generator(Field **arg)

=== modified file 'plugin/memcached_stats/tests/r/describe.result'
--- plugin/memcached_stats/tests/r/describe.result	2010-02-03 22:07:17 +0000
+++ plugin/memcached_stats/tests/r/describe.result	2010-02-04 21:00:20 +0000
@@ -1,6 +1,6 @@
 select table_name
 from data_dictionary.tables
-where table_name like '%memcached%' ORDER BY table_name;
+where table_name like 'memcached%' ORDER BY table_name;
 table_name
 MEMCACHED_ANALYSIS
 MEMCACHED_STATS

=== modified file 'plugin/memcached_stats/tests/t/describe.test'
--- plugin/memcached_stats/tests/t/describe.test	2010-02-03 22:07:17 +0000
+++ plugin/memcached_stats/tests/t/describe.test	2010-02-04 21:00:20 +0000
@@ -3,7 +3,7 @@
 #
 select table_name
 from data_dictionary.tables
-where table_name like '%memcached%' ORDER BY table_name;
+where table_name like 'memcached%' ORDER BY table_name;
 
 #
 # verify the structure of these I_S tables.

=== modified file 'plugin/show_schema_proto/show_schema_proto.cc'
--- plugin/show_schema_proto/show_schema_proto.cc	2009-12-23 21:16:15 +0000
+++ plugin/show_schema_proto/show_schema_proto.cc	2010-02-04 21:00:20 +0000
@@ -81,7 +81,7 @@
   string proto_as_text("");
   message::Schema proto;
 
-  int err= get_database_metadata(db, &proto);
+  int err= get_database_metadata(db, proto);
 
   if (err != 0)
   {

=== modified file 'tests/r/1st.result'
--- tests/r/1st.result	2008-12-06 22:41:03 +0000
+++ tests/r/1st.result	2010-02-04 21:00:20 +0000
@@ -3,5 +3,8 @@
 information_schema
 mysql
 test
+select concat("Starting in ", database());
+concat("Starting in ", database())
+Starting in test
 show tables in mysql;
 Tables_in_mysql

=== modified file 'tests/r/data_dictionary_like_info.result'
--- tests/r/data_dictionary_like_info.result	2010-02-03 20:00:13 +0000
+++ tests/r/data_dictionary_like_info.result	2010-02-04 21:00:20 +0000
@@ -1,14 +1,12 @@
 DROP TABLE IF EXISTS t0,t1,t2,t3,t4,t5;
 DROP SCHEMA IF EXISTS data_dictionary;
 CREATE SCHEMA data_dictionary;
-select * from data_dictionary.SCHEMAS where schema_name > 'm';
-SCHEMA_NAME	DEFAULT_COLLATION_NAME
-select schema_name from data_dictionary.schemas;
-schema_name
-data_dictionary
-information_schema
-
-
+select count(*) from data_dictionary.SCHEMAS where schema_name > 'm';
+count(*)
+#
+select count(*) from data_dictionary.schemas;
+count(*)
+#
 create database mysqltest;
 create table mysqltest.t1(a int, b VARCHAR(30), KEY string_data (b));
 create table test.t2(a int);
@@ -340,12 +338,9 @@
 WHERE ENGINE IS NULL)
 ORDER BY table_name;
 table_name	column_name
-SELECT schema_name FROM data_dictionary.schemas ORDER BY schema_name;
-schema_name
-
-
-data_dictionary
-information_schema
+SELECT count(schema_name) FROM data_dictionary.schemas ORDER BY schema_name;
+count(schema_name)
+#
 SELECT count(*) FROM data_dictionary.session_status ORDER BY variable_name;
 count(*)
 #

=== modified file 'tests/r/information_schema.result'
--- tests/r/information_schema.result	2010-02-04 20:42:07 +0000
+++ tests/r/information_schema.result	2010-02-04 21:00:20 +0000
@@ -6,8 +6,8 @@
 select schema_name from data_dictionary.schemas;
 schema_name
 information_schema
-
-
+mysql
+test
 show databases like 't%';
 Database (t%)
 test
@@ -621,13 +621,9 @@
 SELECT * 
 FROM information_schema.old_referential_constraints;
 CONSTRAINT_CATALOG	CONSTRAINT_SCHEMA	CONSTRAINT_NAME	UNIQUE_CONSTRAINT_CATALOG	UNIQUE_CONSTRAINT_SCHEMA	UNIQUE_CONSTRAINT_NAME	MATCH_OPTION	UPDATE_RULE	DELETE_RULE	TABLE_NAME	REFERENCED_TABLE_NAME
-SELECT schema_name
-FROM data_dictionary.schemas
-ORDER BY schema_name;
-schema_name
-
-
-information_schema
+SELECT count(schema_name) FROM data_dictionary.schemas ORDER BY schema_name;
+count(schema_name)
+#
 SHOW STATUS;
 Variable_name	Value
 #	#
@@ -862,3 +858,6 @@
 information_schema	OLD_TABLES
 information_schema	OLD_TABLE_CONSTRAINTS
 information_schema	OPEN_SESSION_STATUS
+SELECT count(*) FROM data_dictionary.plugins;
+count(*)
+#

=== modified file 'tests/r/schema.result'
--- tests/r/schema.result	2009-01-10 17:58:59 +0000
+++ tests/r/schema.result	2010-02-04 21:00:20 +0000
@@ -5,8 +5,8 @@
 foo	CREATE DATABASE `foo`
 show schemas;
 Database
+foo
 information_schema
-foo
 mysql
 test
 drop schema foo;

=== modified file 'tests/r/show_check.result'
--- tests/r/show_check.result	2010-02-04 20:42:07 +0000
+++ tests/r/show_check.result	2010-02-04 21:00:20 +0000
@@ -95,14 +95,14 @@
 Name	Engine	Version	Row_format	Rows	Avg_row_length	Data_length	Max_data_length	Index_length	Data_free	Auto_increment	Create_time	Update_time	Check_time	Collation	Checksum	Create_options	Comment	Plugin_name
 show databases;
 Catalog	Database	Table	Table_alias	Column	Column_alias	Type	Length	Max length	Is_null	Flags	Decimals	Charsetnr
-def	information_schema	old_schemata	OLD_SCHEMATA	SCHEMA_NAME	Database	8	256	18	N	1	0	45
+def	data_dictionary	schema_names	SCHEMA_NAMES	SCHEMA_NAME	Database	8	256	18	N	1	0	45
 Database
 information_schema
 mysql
 test
 show databases like "test%";
 Catalog	Database	Table	Table_alias	Column	Column_alias	Type	Length	Max length	Is_null	Flags	Decimals	Charsetnr
-def	information_schema	old_schemata	OLD_SCHEMATA	SCHEMA_NAME	Database (test%)	8	256	4	N	1	0	45
+def	data_dictionary	schema_names	SCHEMA_NAMES	SCHEMA_NAME	Database (test%)	8	256	4	N	1	0	45
 Database (test%)
 test
 create table t1 (f1 int not null, f2 int not null, f3 int not null, f4 int not null, primary key(f1,f2,f3,f4));
@@ -486,7 +486,6 @@
 create table `mysqlttest\1`.`a\b` (a int);
 show tables from `mysqlttest\1`;
 Tables_in_mysqlttest\1
-a\b
 show fields from `mysqlttest\1`.`a\b`;
 Field	Type	Null	Key	Default	Extra
 a	int	YES		NULL	

=== modified file 'tests/t/1st.test'
--- tests/t/1st.test	2008-12-06 22:41:03 +0000
+++ tests/t/1st.test	2010-02-04 21:00:20 +0000
@@ -9,4 +9,5 @@
 --enable_warnings
 
 show databases;
+select concat("Starting in ", database());
 show tables in mysql;

=== modified file 'tests/t/data_dictionary_like_info.test'
--- tests/t/data_dictionary_like_info.test	2010-02-04 20:42:07 +0000
+++ tests/t/data_dictionary_like_info.test	2010-02-04 21:00:20 +0000
@@ -7,9 +7,10 @@
 --enable_warnings
 CREATE SCHEMA data_dictionary;
 
-
-select * from data_dictionary.SCHEMAS where schema_name > 'm';
-select schema_name from data_dictionary.schemas;
+--replace_column 1 #
+select count(*) from data_dictionary.SCHEMAS where schema_name > 'm';
+--replace_column 1 #
+select count(*) from data_dictionary.schemas;
 #show databases like 't%';
 #show databases;
 
@@ -422,7 +423,8 @@
 #
 # query the SCHEMAS table
 #
-SELECT schema_name FROM data_dictionary.schemas ORDER BY schema_name;
+--replace_column 1 #
+SELECT count(schema_name) FROM data_dictionary.schemas ORDER BY schema_name;
 
 #
 # Query the STATUS and VARIABLES related

=== modified file 'tests/t/information_schema.test'
--- tests/t/information_schema.test	2010-02-04 20:42:07 +0000
+++ tests/t/information_schema.test	2010-02-04 21:00:20 +0000
@@ -444,9 +444,8 @@
 #
 # query the SCHEMATA table
 #
-SELECT schema_name
-FROM data_dictionary.schemas
-ORDER BY schema_name;
+--replace_column 1 #
+SELECT count(schema_name) FROM data_dictionary.schemas ORDER BY schema_name;
 
 --replace_column 1 # 2 #
 SHOW STATUS;
@@ -488,5 +487,5 @@
 # how do we test for this if the contents of this table can change
 # depend on what plugins are configured for use?
 #
-#SELECT *
-#FROM plugins;
+--replace_column 1 #
+SELECT count(*) FROM data_dictionary.plugins;

=== modified file 'tests/t/select.test'
--- tests/t/select.test	2010-02-04 20:42:07 +0000
+++ tests/t/select.test	2010-02-04 21:00:20 +0000
@@ -3470,4 +3470,4 @@
 EXPLAIN EXTENDED SELECT * FROM t1, t2 WHERE a = b + (1 + 1);
 SELECT * FROM t2 LEFT JOIN t1 ON a = b + 1;
 EXPLAIN EXTENDED SELECT * FROM t2 LEFT JOIN t1 ON a = b + 1;
-EXPLAIN EXTENDED SELECT * FROM t1 WHERE a > UNIX_TIMESTAMP('2009-03-10 00:00:00');
\ No newline at end of file
+EXPLAIN EXTENDED SELECT * FROM t1 WHERE a > UNIX_TIMESTAMP('2009-03-10 00:00:00');

